freerasp library

Classes

AndroidConfig
Class responsible for freeRASP Android configuration
HashConverter
A class for checking and converting SHA-256 hashes.
IOSConfig
Class responsible for freeRASP iOS configuration
PackageInfo
RaspExecutionStateCallback
A callback class that handles RASP (Runtime Application Self-Protection) execution state events.
ScanScope
Configuration for malware scan scope and trusted install sources.
SuspiciousAppDetectionConfig
Configuration for suspicious app detection.
SuspiciousAppInfo
Talsec
A class which maintains all security related operations.
TalsecConfig
Class responsible for freeRASP configuration
ThreatCallback
A class which represents a set of callbacks that are used to notify the application when certain security threat are detected.

Enums

RaspExecutionState
Represents the state of the RASP (Runtime Application Self-Protection) execution.
ReasonMode
The mode for reporting malware detection reasons.
ScopeType
The scope of apps to be scanned for malware.
Threat
Possible threats which can occur in Flutter app.

Extensions

RaspExecutionStateX on RaspExecutionState
Extensions for RaspExecutionState.
ThreatX on Threat
An extension on the Threat enum to provide additional functionality.

Constants

hashConverter → const HashConverter
Static variable for HashConverter.

Typedefs

MalwareCallback = void Function(List<SuspiciousAppInfo?> packageInfo)
Typedef for malware callback
VoidCallback = void Function()
Typedef for void methods

Exceptions / Errors

ConfigurationException
An exception that is thrown when there is a failure with a Talsec configuration.
TalsecException
A base exception class for Talsec exceptions.