ConfigurationException class

An exception that is thrown when there is a failure with a Talsec configuration.

This exception extends the TalsecException class and includes an error code of 'configuration-exception'. It can include an optional message and stackTrace parameter.

Inheritance

Constructors

ConfigurationException({String? message, String? stackTrace})
Constructs and instance of ConfigurationException
const

Properties

code → String
A code which identifies the type of exception.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
message → String?
A message that provides human-readable information about the exception.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stackTrace → String?
A stackTrace for this exception.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited